@@ -55,5 +55,17 @@ $httpd_port = 8888;
 # Read the authentication data from this directory
 $Apache2::Authen::Passphrase::rootdir = "$rootdir/us";
 
+# Email
+# =====
+
+# Delay emails for up to 5 seconds to allow batching
+$email_batch_seconds = 5;
+
+# Send emails from this address
+$email_from = 'FonBot <fonbot@example.com>';
+
+# Send emails with this subject
+$email_subject = 'FonBot message';
+
 # End the configuration file
 return 1;
