@@ -1,6 +1,6 @@
 package App::FonBot::Daemon;
 
-our $VERSION = '0.000_5';
+our $VERSION = '0.001';
 
 use 5.014000;
 use strict;
@@ -14,10 +14,11 @@ use App::FonBot::Plugin::Common;
 use App::FonBot::Plugin::OFTC;
 use App::FonBot::Plugin::BitlBee;
 use App::FonBot::Plugin::HTTPD;
+use App::FonBot::Plugin::Email;
 
 use sigtrap qw/die normal-signals/;
 
-use constant PLUGINS => map { "App::FonBot::Plugin::$_" } qw/Config Common OFTC BitlBee HTTPD/;
+use constant PLUGINS => map { "App::FonBot::Plugin::$_" } qw/Config Common OFTC BitlBee HTTPD Email/;
 
 ##################################################
 
@@ -70,7 +71,7 @@ Marius Gavrilescu C<< <marius@ieval.ro> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2013 Marius Gavrilescu
+Copyright 2013-2015 Marius Gavrilescu
 
 This file is part of fonbotd.
 
