@@ -1,6 +1,6 @@
 package App::FonBot::Plugin::Config;
 
-our $VERSION = '0.000_5';
+our $VERSION = '0.001';
 
 use v5.14;
 use strict;
@@ -11,13 +11,15 @@ use parent qw/Exporter/;
 use Apache2::Authen::Passphrase;
 use Log::Log4perl qw//;
 
-our @EXPORT_OK=qw/$oftc_enabled $oftc_nick @oftc_channels $oftc_nickserv_password $bitlbee_enabled $bitlbee_nick $bitlbee_server $bitlbee_port $bitlbee_password $dir $user $group @supplementary_groups $httpd_port/;
+our @EXPORT_OK=qw/$oftc_enabled $oftc_nick @oftc_channels $oftc_nickserv_password $bitlbee_enabled $bitlbee_nick $bitlbee_server $bitlbee_port $bitlbee_password $dir $user $group @supplementary_groups $httpd_port $email_batch_seconds $email_from $email_subject/;
 
 ##################################################
 
 our ($oftc_enabled, $oftc_nick, @oftc_channels, $oftc_nickserv_password);
 our ($bitlbee_enabled, $bitlbee_nick, $bitlbee_server, $bitlbee_port, $bitlbee_password);
 our ($dir, $user, $group, @supplementary_groups);
+our ($httpd_port);
+our ($email_batch_seconds, $email_from, $email_subject);
 
 ##################################################
 
@@ -71,6 +73,11 @@ App::FonBot::Plugin::Config - FonBot plugin for reading configuration files
   # Variables used in App::FonBot::Plugin::HTTPD
   say "The HTTPD listens on port $httpd_port"
 
+  # Variables used in App::FonBot::Plugin::Email
+  say "The email batch delay is $email_batch_seconds";
+  say "The email plugin sends emails from $email_from";
+  say "The email plugin sends emails with subject $email_subject";
+
 =head1 DESCRIPTION
 
 This FonBot plugin reads a configuration file (hardcoded to F</etc/fonbot/config.pl>) and provides configuration variables to the other plugins. It is a required plugin, since all other plugins depend on it.
@@ -97,7 +104,7 @@ Marius Gavrilescu C<< <marius@ieval.ro> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2013 Marius Gavrilescu
+Copyright 2013-2015 Marius Gavrilescu
 
 This file is part of fonbotd.
 
